#
# spec file for package ghc-split
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name split
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.5
Release:        1.6
Summary:        Combinator library for splitting lists
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
%endif

%description
A collection of various methods for splitting lists into parts, akin to the
"split" function found in several mainstream languages. Here is its tale:

Once upon a time the standard "Data.List" module held no function for splitting
a list into parts according to a delimiter. Many a brave lambda-knight strove
to add such a function, but their striving was in vain, for Lo, the Supreme
Council fell to bickering amongst themselves what was to be the essential
nature of the One True Function which could cleave a list in twain (or thrain,
or any required number of parts).

And thus came to pass the split package, comprising divers functions for
splitting a list asunder, each according to its nature. And the Supreme Council
had no longer any grounds for argument, for the favored method of each was
contained therein.

To get started, see the "Data.List.Split" module.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Jan 11 2024 Peter Simons <psimons@suse.com>
- Update split to version 0.2.5.
  * 0.2.5 (9 January 2024)
  - Test with GHC 9.8.
  - New function `mapSplitter` witnessing the fact that `Splitter` is
    a contravariant functor
    ([#22](https://github.com/byorgey/split/pull/22), thanks to Ellis
    Kesterton)
* Mon Oct  9 2023 Peter Simons <psimons@suse.com>
- Update split to version 0.2.4.
  * 0.2.4 (9 October 2023)
  - Test with GHC 9.6.
  - Change examples to doctests (+ add a few more), and check them as part of CI.
  - Fix up a bunch of style hints.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Aug 11 2022 Peter Simons <psimons@suse.com>
- Update split to version 0.2.3.5.
  * 0.2.3.5 (11 August 2022)
  - Change base upper bound to < 5.
  - Test with GHC 9.2 and 9.4.
  * 0.2.3.4-r1 (22 February 2021)
  - Allow base-4.15 for GHC-9.0
* Tue Feb 15 2022 Peter Simons <psimons@suse.com>
- Update copyright header in the spec file.
* Fri Feb 11 2022 Peter Simons <psimons@suse.com>
- Make sure installed text files have no +x flag.
* Wed Sep 22 2021 psimons@suse.com
- Update split to version 0.2.3.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Sep  7 2021 Ondřej Súkup <mimi.vx@gmail.com>
- make rpmlint happy
* Tue Feb 23 2021 psimons@suse.com
- Update split to version 0.2.3.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu Feb 27 2020 psimons@suse.com
- Update split to version 0.2.3.4.
  * 0.2.3.4 (22 February 2020)
  - Allow base-4.14 for GHC-8.10
  * 0.2.3.3-r2 (19 August 2019)
  - Allow base-4.13 for GHC-8.8
  * 0.2.3.3-r1 (2 August 2018)
  - Allow base-4.12 for GHC-8.6
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Tue Aug  7 2018 psimons@suse.com
- Update Cabal build information to GHC 8.6.x.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update split to version 0.2.3.3.
  * Update for GHC-8.4, test with GHC 7.0-8.4
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu May 18 2017 psimons@suse.com
- Update to version 0.2.3.2 with cabal2obs.
* Sat Apr 29 2017 psimons@suse.com
- Update to version 0.2.3.1 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2.3.1 revision 0 with cabal2obs.
* Wed May  4 2016 mimi.vx@gmail.com
- update to 0.2.3.1
  * Fix a test case which was causing occasional spurious test suite
    failures due to too many discarded tests.
* Fri Jan 15 2016 mimi.vx@gmail.com
- update to 0.2.3
  * New function 'divvy' (with associated tests) from Tim Washington.
  * allow base 4.9
- drop patch split-base.patch
* Tue May 12 2015 mimi.vx@gmail.com
- regenerated spec file
- add split-base.patch change dep constrains in cabal file
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerated spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 0.2.2 from upstream
  * make splitting lazier (patch from Daniel Wagner)
  * allow base library version 4.7
  * new dropInnerBlanks combinator
- update is part of Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Sun Dec 30 2012 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.2.1.1 from upstream
- required by Haskell Platform 2012.4.0.0
* Thu May 17 2012 peter.trommler@ohm-hochschule.de
- spec file template generated by cabal2spec-0.25.5
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
